donut.hooked


defhookclj/s

(defhook hook-name docstring & [arg-schema])

hookclj/s

(hook hook-name arg)

call a hook if it's defined

call a hook if it's defined
raw docstring

hooksclj/s


set-hook-fn!clj/s

(set-hook-fn! hook-name f)

installs a function to call when the hook gets called

installs a function to call when the hook gets called
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries