(defhook hook-name docstring & [arg-schema])(set-hook-fn! hook-name f)installs a function to call when the hook gets called
installs a function to call when the hook gets called
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |